namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Progressbar::pulse_get() const
{
   Eina_Bool __return_value =  ::elm_obj_progressbar_pulse_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progressbar::pulse_set( ::efl::eolian::in_traits<bool>::type pulse) const
{
    ::elm_obj_progressbar_pulse_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(pulse));
}
inline ::efl::eolian::return_traits<void>::type Progressbar::part_value_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type part,  ::efl::eolian::in_traits<double>::type val) const
{
    ::elm_obj_progressbar_part_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(part)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(val));
}
inline ::efl::eolian::return_traits<double>::type Progressbar::part_value_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type part) const
{
   double __return_value =  ::elm_obj_progressbar_part_value_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(part));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progressbar::pulse( ::efl::eolian::in_traits<bool>::type state) const
{
    ::elm_obj_progressbar_pulse(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(state));
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Progressbar::pulse_get() const
{
   Eina_Bool __return_value =  ::elm_obj_progressbar_pulse_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progressbar::pulse_set( ::efl::eolian::in_traits<bool>::type pulse) const
{
    ::elm_obj_progressbar_pulse_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(pulse));
}
inline ::efl::eolian::return_traits<void>::type Progressbar::part_value_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type part,  ::efl::eolian::in_traits<double>::type val) const
{
    ::elm_obj_progressbar_part_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(part)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(val));
}
inline ::efl::eolian::return_traits<double>::type Progressbar::part_value_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type part) const
{
   double __return_value =  ::elm_obj_progressbar_part_value_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(part));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progressbar::pulse( ::efl::eolian::in_traits<bool>::type state) const
{
    ::elm_obj_progressbar_pulse(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(state));
}
inline elm::Progressbar::operator ::elm::Progressbar() const { return *static_cast< ::elm::Progressbar const*>(static_cast<void const*>(this)); }
inline elm::Progressbar::operator ::elm::Progressbar&() { return *static_cast< ::elm::Progressbar*>(static_cast<void*>(this)); }
inline elm::Progressbar::operator ::elm::Progressbar const&() const { return *static_cast< ::elm::Progressbar const*>(static_cast<void const*>(this)); }
} }

